# CHANGELOG

## v0.4.0 (2026-01-04)

### Feature

* feat: sync semantic release configuration ([`5258017`](https://github.com/luutuankiet/fs-mcp/commit/525801749d2c1890431d055819b750ddb4f35f42))

### Fix

* fix: sync semantic version in pyproject.toml ([`c8179e4`](https://github.com/luutuankiet/fs-mcp/commit/c8179e4ea595387eb67162227c7169a4760710fd))

## v0.3.0 (2026-01-04)

### Chore

* chore: cleanup old artifacts &amp; update readme ([`1c2e192`](https://github.com/luutuankiet/fs-mcp/commit/1c2e1923051c81a2247d66af595d33f87ec1f360))

### Feature

* feat: uses google-genai to convert gemini-compatible json schema ([`e12a99b`](https://github.com/luutuankiet/fs-mcp/commit/e12a99b303be80ae17ff0e8b945c55513ec31b54))

## v0.2.0 (2026-01-04)

### Chore

* chore: webui tool sorted by order ([`69ab178`](https://github.com/luutuankiet/fs-mcp/commit/69ab17880f0f7165b3f04765764904c53de1df11))

* chore: bump version ([`c7729c7`](https://github.com/luutuankiet/fs-mcp/commit/c7729c7418eb991a7bdab5875750444190059538))

### Feature

* feat: roo-style edit file tool and fallback append tool ([`38f5059`](https://github.com/luutuankiet/fs-mcp/commit/38f5059526c1b8943f2b5500c47a2e9c9ab31be2))

* feat: auto copy tool response to clipboard ([`d1eba6b`](https://github.com/luutuankiet/fs-mcp/commit/d1eba6b5566fa5e8a8dfc03cc368a18fab9157f9))

* feat: dual mode in --ui to spin up both streamlit client and http mcp server ([`51a9074`](https://github.com/luutuankiet/fs-mcp/commit/51a9074639825a342958c312250f8ef6e1b3a904))

* feat: web ui uses native fastmcp for emitting jsonschema ([`de79be6`](https://github.com/luutuankiet/fs-mcp/commit/de79be6a1cb616e9bc3e06d0ab3fabbd965f2568))

### Fix

* fix: precise line for edit_file ([`e889945`](https://github.com/luutuankiet/fs-mcp/commit/e8899452b05367b166256463067300be6bada262))

## v0.1.0 (2026-01-04)

### Chore

* chore: add pypi release GHA ([`31a7bf3`](https://github.com/luutuankiet/fs-mcp/commit/31a7bf3cc6f9b694fecd34e69283543c912870ca))

### Feature

* feat: add multi file read ([`1098427`](https://github.com/luutuankiet/fs-mcp/commit/1098427164317b44363d7aa64420c9d0afc49678))

### Unknown

* docs : add readme ([`c3a7218`](https://github.com/luutuankiet/fs-mcp/commit/c3a72188c895cbc4b45d0d350ba22ef0b4143d3d))

* init ([`e9d86de`](https://github.com/luutuankiet/fs-mcp/commit/e9d86de61a6f2e7ae1b12afc27c6e1c876705cbe))
